@@ -2,7 +2,7 @@ from acceldata_sdk.errors import TorchSdkException
 from acceldata_sdk.models.pipeline import CreatePipeline, Pipeline, PipelineRun
 from acceldata_sdk.torch_http_client import TorchHttpClient
 from acceldata_sdk.constants import RuleExecutionStatus, FailureStrategy, PolicyType, AssetSourceType, \
-    MIN_TORCH_BACKEND_VERSION_SUPPORTED, SdkSupportedVersions, TorchBuildVersion
+    MIN_TORCH_BACKEND_VERSION_SUPPORTED, SdkSupportedVersions, TorchBuildVersion, PipelineBulkupdateRequest
 
 from acceldata_sdk.models.rule import RuleResource
 from typing import List
@@ -347,3 +347,6 @@ class TorchClient:
         :param sortBy: (Str) sorting order
         """
         return self.client.policy_executions(identifier, policy_type, page, size, sortBy)
+
+    def bulkupdate_pipeline(self, bulkUpdateRequest: PipelineBulkupdateRequest):
+        return self.client.bulkupdate_pipeline(bulkUpdateRequest)
\ No newline at end of file
