@@ -23,12 +23,12 @@ from acceldata_sdk.models.reconcillationrule import ReconcillationExecutionResul
 from acceldata_sdk.models.ruleExecutionResult import RuleResult, PolicyFilter, ExecutionPeriod, RuleType, RuleExecutionSummary
 from acceldata_sdk.constants import AssetSourceType, SdkSupportedVersions, TorchBuildVersion
 from acceldata_sdk.common import Executor
-from acceldata_sdk.constants import PolicyType, FailureStrategy, RuleExecutionStatus
+from acceldata_sdk.constants import PolicyType, FailureStrategy, RuleExecutionStatus, PipelineBulkupdateRequest
 from semantic_version import Version, SimpleSpec
 
 
 from typing import List
-from dataclasses import asdict
+from dataclasses import asdict, dataclass
 import json
 from datetime import datetime, timedelta
 
@@ -73,8 +73,9 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         self._timeout = 10000
         self._catalog_api_base = f"{url}{catalog_api_path}"
         self._pipeline_api_base = f"{url}{pipeline_api_path}"
+        is_ends_with_torch = url.endswith('/torch')
         loc = url.rfind('/torch')
-        if loc > 0:
+        if is_ends_with_torch:
             self._admin_api_base = f"{url[:loc]}{admin_api_path}"
         else:
             self._admin_api_base = f"{url}{admin_api_path}"
@@ -130,6 +131,23 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         self.logger.info('Pipeline Created')
         return Pipeline(**response['pipeline'])
 
+
+    def bulkupdate_pipeline(self, bulkUpdateRequest: PipelineBulkupdateRequest):
+        """
+        Description:
+            Used to bulk update pipeline
+        :param pipeline: createPipeline class instance that you want to create
+        :return: pipeline class instance
+        """
+        payload = asdict(bulkUpdateRequest)
+        response = self._post(
+            f'{self._pipeline_api_base}/pipelines/bulkupdate',
+            payload=payload, as_json=False
+        )
+        # response['pipeline']['client'] = self
+        self.logger.info(f'Pipelines Created')
+        return response
+
     # function to delete pipeline
     def delete_pipeline(self, id):
         """
